const express = require('express');
const bcrypt = require('bcryptjs');
const User = require('../models/user');
const router = express.Router();

// Register User
router.post('/register', async (req, res) => {
  const { username, password } = req.body;
  
  try {
    // Verify if the user exists
    const existingUser = await User.findOne({ username });
    if (existingUser) {
      return res.status(400).json({ error: 'User already exists' });
    }

    // Encrypt the password
    const hashedPassword = await bcrypt.hash(password, 10); 

    // Creating a new user with the encrypted password
    const user = new User({ username, password: hashedPassword });
    await user.save();

    res.status(201).json({ success: true, message: 'User registered successfully' });
  } catch (error) {
    console.error('Error saving user:', error);
    res.status(500).json({ error: 'Server error' });
  }
});

// LogIn User
router.post('/login', async (req, res) => {
  const { username, password } = req.body;
  console.log('Attempting to log in:', username);

  try {
    const user = await User.findOne({ username });
    console.log('User found:', user);

    if (!user) {
      return res.status(400).json({ error: 'Invalid username or password' });
    }

    const isMatch = await bcrypt.compare(password, user.password);
    console.log('Password match:', isMatch);

    if (!isMatch) {
      return res.status(400).json({ error: 'Invalid username or password' });
    }

    req.session.user = { id: user._id, username: user.username };
    console.log('User logged in:', req.session.user);

    res.json({ success: true, message: 'Login successful' });
  } catch (error) {
    console.error('Login error:', error);
    res.status(500).json({ error: 'Server error' });
  }
});

// Checking if the user is logged in
router.post('/loggedin', (req, res) => {
  try {
    if (!req.session.user) {
      res.status(403).json({ error: 'Unauthorized' });
    }
  } catch (error) {
    console.error('Authorization check failed:', error);
    res.status(500).json({ error: 'Server error' });
  }
});

// Closing user session
router.post('/logout', (req, res) => {
  req.session.destroy(err => {
    if (err) {
      return res.status(500).json({ error: 'Logout failed' });
    }
    res.json({ success: true, message: 'Logged out successfully' });
  });
});

module.exports = router;